Enum scilla_parser::ast::nodes::NodeComponentId
source · pub enum NodeComponentId {
WithTypeLikeName(WithMetaData<NodeTypeNameIdentifier>),
WithRegularId(WithMetaData<String>),
}Expand description
NodeComponentId represents a component id node in the AST It can either be a WithTypeLikeName or a WithRegularId
Variants
WithTypeLikeName(WithMetaData<NodeTypeNameIdentifier>)
Represents a component id with a type like name
Example: component WithTypeLikeName;
WithRegularId(WithMetaData<String>)
Represents a component id with a regular id
Example: component WithRegularId;