pub enum NodeRemoteFetchStatement {
    ReadStateMutable(WithMetaData<String>, WithMetaData<String>, WithMetaData<NodeVariableIdentifier>),
    ReadStateMutableSpecialId(WithMetaData<String>, WithMetaData<String>, WithMetaData<String>),
    ReadStateMutableMapAccess(WithMetaData<String>, WithMetaData<String>, WithMetaData<String>, Vec<WithMetaData<NodeMapAccess>>),
    ReadStateMutableMapAccessExists(WithMetaData<String>, WithMetaData<String>, WithMetaData<String>, Vec<WithMetaData<NodeMapAccess>>),
    ReadStateMutableCastAddress(WithMetaData<String>, WithMetaData<NodeVariableIdentifier>, WithMetaData<NodeAddressType>),
}
NodeRemoteFetchStatement represents a remote fetch statement node in the AST It can be one of many different types of remote fetch statements

Variants



ReadStateMutable(WithMetaData<String>, WithMetaData<String>, WithMetaData<NodeVariableIdentifier>)

Represents a read state mutable statement Example: read x from state;



ReadStateMutableSpecialId(WithMetaData<String>, WithMetaData<String>, WithMetaData<String>)

Represents a read state mutable special id statement Example: read x from state with id;



ReadStateMutableMapAccess(WithMetaData<String>, WithMetaData<String>, WithMetaData<String>, Vec<WithMetaData<NodeMapAccess>>)

Represents a read state mutable map access statement Example: read x from state with map access;



ReadStateMutableMapAccessExists(WithMetaData<String>, WithMetaData<String>, WithMetaData<String>, Vec<WithMetaData<NodeMapAccess>>)

Represents a read state mutable map access exists statement Example: read x from state with map access if exists;



ReadStateMutableCastAddress(WithMetaData<String>, WithMetaData<NodeVariableIdentifier>, WithMetaData<NodeAddressType>)

Represents a read state mutable cast address statement Example: read x from state with cast address;