Struct scilla_parser::ast::nodes::NodeAddressType
source · pub struct NodeAddressType {
pub identifier: WithMetaData<NodeTypeNameIdentifier>,
pub type_name: WithMetaData<String>,
pub address_fields: Vec<WithMetaData<NodeAddressTypeField>>,
}Expand description
NodeAddressType represents an address type node in the AST
Fields
identifier: WithMetaData<NodeTypeNameIdentifier>type_name: WithMetaData<String>address_fields: Vec<WithMetaData<NodeAddressTypeField>>Trait Implementations
sourceimpl AstVisitor for NodeAddressType
impl AstVisitor for NodeAddressType
fn visit( &self, emitter: &mut dyn AstConverting ) -> Result<TraversalResult, String>
sourceimpl Clone for NodeAddressType
impl Clone for NodeAddressType
sourcefn clone(&self) -> NodeAddressType
fn clone(&self) -> NodeAddressType
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for NodeAddressType
impl Debug for NodeAddressType
sourceimpl PartialEq for NodeAddressType
impl PartialEq for NodeAddressType
sourcefn eq(&self, other: &NodeAddressType) -> bool
fn eq(&self, other: &NodeAddressType) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for NodeAddressType
impl PartialOrd for NodeAddressType
sourcefn partial_cmp(&self, other: &NodeAddressType) -> Option<Ordering>
fn partial_cmp(&self, other: &NodeAddressType) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl Eq for NodeAddressType
impl StructuralEq for NodeAddressType
impl StructuralPartialEq for NodeAddressType