Struct scilla_parser::ast::nodes::NodeAddressTypeField
source · pub struct NodeAddressTypeField {
pub identifier: WithMetaData<NodeVariableIdentifier>,
pub type_name: WithMetaData<NodeScillaType>,
}Expand description
NodeAddressTypeField represents an address type field node in the AST
Fields
identifier: WithMetaData<NodeVariableIdentifier>type_name: WithMetaData<NodeScillaType>Trait Implementations
sourceimpl AstVisitor for NodeAddressTypeField
impl AstVisitor for NodeAddressTypeField
fn visit( &self, emitter: &mut dyn AstConverting ) -> Result<TraversalResult, String>
sourceimpl Clone for NodeAddressTypeField
impl Clone for NodeAddressTypeField
sourcefn clone(&self) -> NodeAddressTypeField
fn clone(&self) -> NodeAddressTypeField
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for NodeAddressTypeField
impl Debug for NodeAddressTypeField
sourceimpl PartialEq for NodeAddressTypeField
impl PartialEq for NodeAddressTypeField
sourcefn eq(&self, other: &NodeAddressTypeField) -> bool
fn eq(&self, other: &NodeAddressTypeField) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for NodeAddressTypeField
impl PartialOrd for NodeAddressTypeField
sourcefn partial_cmp(&self, other: &NodeAddressTypeField) -> Option<Ordering>
fn partial_cmp(&self, other: &NodeAddressTypeField) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl Eq for NodeAddressTypeField
impl StructuralEq for NodeAddressTypeField
impl StructuralPartialEq for NodeAddressTypeField