Struct scilla_parser::ast::nodes::NodeBuiltinArguments
source · pub struct NodeBuiltinArguments {
pub arguments: Vec<WithMetaData<NodeVariableIdentifier>>,
}Expand description
NodeBuiltinArguments represents a list of arguments for a built-in function in the AST
Fields
arguments: Vec<WithMetaData<NodeVariableIdentifier>>Trait Implementations
sourceimpl AstVisitor for NodeBuiltinArguments
impl AstVisitor for NodeBuiltinArguments
fn visit( &self, emitter: &mut dyn AstConverting ) -> Result<TraversalResult, String>
sourceimpl Clone for NodeBuiltinArguments
impl Clone for NodeBuiltinArguments
sourcefn clone(&self) -> NodeBuiltinArguments
fn clone(&self) -> NodeBuiltinArguments
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for NodeBuiltinArguments
impl Debug for NodeBuiltinArguments
sourceimpl PartialEq for NodeBuiltinArguments
impl PartialEq for NodeBuiltinArguments
sourcefn eq(&self, other: &NodeBuiltinArguments) -> bool
fn eq(&self, other: &NodeBuiltinArguments) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for NodeBuiltinArguments
impl PartialOrd for NodeBuiltinArguments
sourcefn partial_cmp(&self, other: &NodeBuiltinArguments) -> Option<Ordering>
fn partial_cmp(&self, other: &NodeBuiltinArguments) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl Eq for NodeBuiltinArguments
impl StructuralEq for NodeBuiltinArguments
impl StructuralPartialEq for NodeBuiltinArguments