Struct scilla_parser::ast::nodes::NodeContractDefinition
source · pub struct NodeContractDefinition {
pub contract_name: WithMetaData<NodeTypeNameIdentifier>,
pub parameters: WithMetaData<NodeComponentParameters>,
pub constraint: Option<WithMetaData<NodeWithConstraint>>,
pub fields: Vec<WithMetaData<NodeContractField>>,
pub components: Vec<WithMetaData<NodeComponentDefinition>>,
}Expand description
NodeContractDefinition represents a contract definition node in the AST It contains a contract name, parameters, optional constraint, fields and components
Fields
contract_name: WithMetaData<NodeTypeNameIdentifier>The contract name of the contract definition
parameters: WithMetaData<NodeComponentParameters>The parameters of the contract definition
constraint: Option<WithMetaData<NodeWithConstraint>>The constraint of the contract definition
fields: Vec<WithMetaData<NodeContractField>>The fields of the contract definition
components: Vec<WithMetaData<NodeComponentDefinition>>The components of the contract definition