Struct scilla_parser::ast::nodes::NodeImportDeclarations
source · pub struct NodeImportDeclarations {
pub import_list: Vec<WithMetaData<NodeImportedName>>,
}Expand description
NodeImportDeclarations represents a list of import declarations in the AST
Fields
import_list: Vec<WithMetaData<NodeImportedName>>Trait Implementations
sourceimpl AstVisitor for NodeImportDeclarations
impl AstVisitor for NodeImportDeclarations
fn visit( &self, emitter: &mut dyn AstConverting ) -> Result<TraversalResult, String>
sourceimpl Clone for NodeImportDeclarations
impl Clone for NodeImportDeclarations
sourcefn clone(&self) -> NodeImportDeclarations
fn clone(&self) -> NodeImportDeclarations
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for NodeImportDeclarations
impl Debug for NodeImportDeclarations
sourceimpl PartialEq for NodeImportDeclarations
impl PartialEq for NodeImportDeclarations
sourcefn eq(&self, other: &NodeImportDeclarations) -> bool
fn eq(&self, other: &NodeImportDeclarations) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for NodeImportDeclarations
impl PartialOrd for NodeImportDeclarations
sourcefn partial_cmp(&self, other: &NodeImportDeclarations) -> Option<Ordering>
fn partial_cmp(&self, other: &NodeImportDeclarations) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl Eq for NodeImportDeclarations
impl StructuralEq for NodeImportDeclarations
impl StructuralPartialEq for NodeImportDeclarations