Struct scilla_parser::ast::nodes::NodeLibraryDefinition
source · pub struct NodeLibraryDefinition {
pub name: WithMetaData<NodeTypeNameIdentifier>,
pub definitions: Vec<WithMetaData<NodeLibrarySingleDefinition>>,
}Expand description
NodeLibraryDefinition represents a library definition node in the AST It contains a name and a vector of definitions
Fields
name: WithMetaData<NodeTypeNameIdentifier>The name of the library definition
definitions: Vec<WithMetaData<NodeLibrarySingleDefinition>>The definitions of the library definition