Struct scilla_parser::ast::nodes::NodeTypeMapEntry
source · pub struct NodeTypeMapEntry {
pub key: WithMetaData<NodeTypeMapKey>,
pub value: WithMetaData<NodeTypeMapValue>,
}Expand description
NodeTypeMapEntry represents a type map entry node in the AST
Fields
key: WithMetaData<NodeTypeMapKey>value: WithMetaData<NodeTypeMapValue>Trait Implementations
sourceimpl AstVisitor for NodeTypeMapEntry
impl AstVisitor for NodeTypeMapEntry
fn visit( &self, emitter: &mut dyn AstConverting ) -> Result<TraversalResult, String>
sourceimpl Clone for NodeTypeMapEntry
impl Clone for NodeTypeMapEntry
sourcefn clone(&self) -> NodeTypeMapEntry
fn clone(&self) -> NodeTypeMapEntry
Returns a copy of the value. Read more
1.0.0 · sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moresourceimpl Debug for NodeTypeMapEntry
impl Debug for NodeTypeMapEntry
sourceimpl PartialEq for NodeTypeMapEntry
impl PartialEq for NodeTypeMapEntry
sourcefn eq(&self, other: &NodeTypeMapEntry) -> bool
fn eq(&self, other: &NodeTypeMapEntry) -> bool
This method tests for
self and other values to be equal, and is used
by ==.sourceimpl PartialOrd for NodeTypeMapEntry
impl PartialOrd for NodeTypeMapEntry
sourcefn partial_cmp(&self, other: &NodeTypeMapEntry) -> Option<Ordering>
fn partial_cmp(&self, other: &NodeTypeMapEntry) -> Option<Ordering>
1.0.0 · sourcefn le(&self, other: &Rhs) -> bool
fn le(&self, other: &Rhs) -> bool
This method tests less than or equal to (for
self and other) and is used by the <=
operator. Read moreimpl Eq for NodeTypeMapEntry
impl StructuralEq for NodeTypeMapEntry
impl StructuralPartialEq for NodeTypeMapEntry