Struct scilla_parser::ast::nodes::NodeTypedIdentifier
source · pub struct NodeTypedIdentifier {
pub identifier_name: WithMetaData<String>,
pub annotation: WithMetaData<NodeTypeAnnotation>,
}Expand description
NodeTypedIdentifier represents a typed identifier node in the AST It contains an identifier name and an annotation
Fields
identifier_name: WithMetaData<String>The identifier name of the typed identifier
annotation: WithMetaData<NodeTypeAnnotation>The annotation of the typed identifier